/**********************************************************************
 *     EPSCAN, an EPSON ES-1200 scanner driver     
 *     Adam P. Jenkins <ajenkins@cs.umass.edu>
 *     
 *     This program is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU General Public License
 *     as published by the Free Software Foundation; either version 2
 *     of the License, or (at your option) any later version.
 *     
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *     
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **********************************************************************/

#include <qlayout.h>
#include <qpushbt.h>

#include "Scanner.h"
#include "qprogres.h"
#include "ProgressReport.h"

ProgressReport::ProgressReport(Scanner *dev, QWidget *parent, const char *name)
: QDialog(parent, name, TRUE)
{
  Dev = dev;
  
  progressBar = new QProgressCtrl(this, solidBar);
  CHECK_PTR(progressBar);

  progressBar->setRange(0, dev->scanSize());
  progressBar->setPos(0);
  progressBar->setGeometry(5, 5, 300, 30);

  QPushButton *cancelBn = new QPushButton("Cancel", this);
  CHECK_PTR(cancelBn);
  cancelBn->move((progressBar->width() - cancelBn->width()) / 2,
		 progressBar->rect().bottom() + 15);
  connect(cancelBn, SIGNAL(clicked()), SLOT(cancelScan()) );
  cancel = false;

  startTimer(0);
}

ProgressReport::~ProgressReport()
{
  delete progressBar;
}

void
ProgressReport::timerEvent(QTimerEvent *)
{
  int bytesRead = Dev->scanBlock(cancel);
  if (bytesRead < 0) {
    warning("Scanner error: %s", Dev->strError());
    killTimers();
    done(-1);
  } else if (bytesRead == 0) {
    killTimers();
    done(cancel ? -1 : 0);
  } else {
    progressBar->offsetPos(bytesRead);
  }
}

void
ProgressReport::cancelScan()
{
  cancel = true;
}
